@@ -90,8 +90,8 @@ plotAttractors <- function (attractorInfo, subset, title = "", mode=c("table","g
             abline(v = sep[-1],col="white",lwd=3)
             
         # output frequency of attractor (basin size / number of states)
-        freq <- sapply(attractorInfo$attractors[intersect(which(attractorLengths == len),subset)],
-            function(attractor)attractor$basinSize/length(attractorInfo$stateInfo$table)) * 100
+        freq <- round(sapply(attractorInfo$attractors[intersect(which(attractorLengths == len),subset)],
+            function(attractor)attractor$basinSize/length(attractorInfo$stateInfo$table)) * 100,2)
 
         if (!isTRUE(all(is.na(freq))))
         {
